@@ -9,7 +9,8 @@ class ProductFees(Client):
 
     @sp_endpoint('/products/fees/v0/listings/{}/feesEstimate', method='POST')
     def get_product_fees_estimate_for_sku(self, seller_sku, price: float, shipping_price=None, currency='USD',
-                                          is_fba=False, points: dict = None, **kwargs) -> ApiResponse:
+                                          is_fba=False, points: dict = None, marketplace_id: str = None,
+                                          **kwargs) -> ApiResponse:
         """
         get_product_fees_estimate_for_sku(self, seller_sku, price: float, shipping_price=None, currency='USD', is_fba=False, points: dict = dict, **kwargs) -> ApiResponse
 
@@ -34,18 +35,19 @@ class ProductFees(Client):
             currency:
             is_fba:
             points:
+            marketplace_id: str | Defaults to self.marketplace_id
             **kwargs:
 
         Returns:
             ApiResponse:
 
         """
-        kwargs.update(self._create_body(price, shipping_price, currency, is_fba, seller_sku, points))
+        kwargs.update(self._create_body(price, shipping_price, currency, is_fba, seller_sku, points, marketplace_id))
         return self._request(fill_query_params(kwargs.pop('path'), seller_sku), data=kwargs)
 
     @sp_endpoint('/products/fees/v0/items/{}/feesEstimate', method='POST')
     def get_product_fees_estimate_for_asin(self, asin, price: float, currency='USD', shipping_price=None, is_fba=False,
-                                           points: dict = None,
+                                           points: dict = None, marketplace_id: str = None,
                                            **kwargs) -> ApiResponse:
         """
         get_product_fees_estimate_for_asin(self, asin, price: float, currency='USD', shipping_price=None, is_fba=False,  points: dict = dict, **kwargs) -> ApiResponse
@@ -71,16 +73,18 @@ class ProductFees(Client):
             shipping_price:
             is_fba:
             points:
+            marketplace_id: str | Defaults to self.marketplace_id
             **kwargs:
 
         Returns:
             ApiResponse:
 
         """
-        kwargs.update(self._create_body(price, shipping_price, currency, is_fba, asin, points))
+        kwargs.update(self._create_body(price, shipping_price, currency, is_fba, asin, points, marketplace_id))
         return self._request(fill_query_params(kwargs.pop('path'), asin), data=kwargs)
 
-    def _create_body(self, price, shipping_price=None, currency='USD', is_fba=False, identifier=None, points: dict=None):
+    def _create_body(self, price, shipping_price=None, currency='USD', is_fba=False, identifier=None,
+                     points: dict = None, marketplace_id: str = None):
         """
         Create request body
 
@@ -110,6 +114,6 @@ class ProductFees(Client):
                     'Points': points or None
                 },
                 'IsAmazonFulfilled': is_fba,
-                'MarketplaceId': self.marketplace_id
+                'MarketplaceId': marketplace_id or self.marketplace_id
             }
         }
